@@ -130,6 +130,16 @@ Compiler::valid(UStringView dir) const
   return true;
 }
 
+void
+Compiler::step(UString& name)
+{
+  int ret = xmlTextReaderRead(reader);
+  if (ret == -1) {
+    XMLParseUtil::error_and_die(reader, "Parse error.");
+  }
+  name = XMLParseUtil::readName(reader);
+}
+
 void
 Compiler::procAlphabet()
 {
@@ -157,9 +167,7 @@ Compiler::procAlphabet()
     }
     else
     {
-      std::cerr << "Error (" << xmlTextReaderGetParserLineNumber(reader);
-      std::cerr << "): Missing alphabet symbols." << std::endl;
-      exit(EXIT_FAILURE);
+      XMLParseUtil::error_and_die(reader, "Missing alphabet symbols.");
     }
   }
 }
@@ -359,9 +367,7 @@ Compiler::readString(std::vector<int> &result, UStringView name)
 
     if(!alphabet.isSymbolDefined(symbol))
     {
-      std::cerr << "Error (" << xmlTextReaderGetParserLineNumber(reader);
-      std::cerr << "): Undefined symbol '" << symbol << "'." << std::endl;
-      exit(EXIT_FAILURE);
+      XMLParseUtil::error_and_die(reader, "Undefined symbol '%S'.", symbol.c_str());
     }
 
     result.push_back(alphabet(symbol));
@@ -385,6 +391,10 @@ Compiler::readString(std::vector<int> &result, UStringView name)
       result.push_back(word_boundary);
     }
   }
+  else if (is_separable && name == COMPILER_LSX_FORM_SEP_ELEM) {
+    requireEmptyError(name);
+    result.push_back(reading_boundary);
+  }
   else
   {
     std::cerr << "Error (" << xmlTextReaderGetParserLineNumber(reader);
@@ -403,22 +413,18 @@ Compiler::skipBlanks(UString &name)
     {
       if(!allBlanks())
       {
-        std::cerr << "Error (" << xmlTextReaderGetParserLineNumber(reader);
-        std::cerr << "): Invalid construction." << std::endl;
-        exit(EXIT_FAILURE);
+	XMLParseUtil::error_and_die(reader, "Invalid construction.");
       }
     }
 
-    xmlTextReaderRead(reader);
-    name = XMLParseUtil::readName(reader);
+    step(name);
   }
 }
 
 void
 Compiler::skip(UString &name, UStringView elem, bool open)
 {
-  xmlTextReaderRead(reader);
-  name = XMLParseUtil::readName(reader);
+  step(name);
   UString slash;
 
   if(!open)
@@ -432,13 +438,10 @@ Compiler::skip(UString &name, UStringView elem, bool open)
     {
       if(!allBlanks())
       {
-        std::cerr << "Error (" << xmlTextReaderGetParserLineNumber(reader);
-        std::cerr << "): Invalid construction." << std::endl;
-        exit(EXIT_FAILURE);
+	XMLParseUtil::error_and_die(reader, "Invalid construction.");
       }
     }
-    xmlTextReaderRead(reader);
-    name = XMLParseUtil::readName(reader);
+    step(name);
   }
 
   if(name != elem)
@@ -460,8 +463,7 @@ Compiler::procIdentity(double const entry_weight, bool ig)
 
     while(true)
     {
-      xmlTextReaderRead(reader);
-      name = XMLParseUtil::readName(reader);
+      step(name);
       if(name == COMPILER_IDENTITY_ELEM || name == COMPILER_IDENTITYGROUP_ELEM)
       {
         break;
@@ -501,15 +503,9 @@ Compiler::procTransduction(double const entry_weight)
 
   if(!xmlTextReaderIsEmptyElement(reader))
   {
-    name.clear();
-    while(true)
-    {
-      xmlTextReaderRead(reader);
-      name = XMLParseUtil::readName(reader);
-      if(name == COMPILER_LEFT_ELEM)
-      {
-        break;
-      }
+    while (true) {
+      step(name);
+      if (name == COMPILER_LEFT_ELEM) break;
       readString(lhs, name);
     }
   }
@@ -525,15 +521,9 @@ Compiler::procTransduction(double const entry_weight)
 
   if(!xmlTextReaderIsEmptyElement(reader))
   {
-    name.clear();
-    while(true)
-    {
-      xmlTextReaderRead(reader);
-      name = XMLParseUtil::readName(reader);
-      if(name == COMPILER_RIGHT_ELEM)
-      {
-        break;
-      }
+    while (true) {
+      step(name);
+      if (name == COMPILER_RIGHT_ELEM) break;
       readString(rhs, name);
     }
   }
@@ -560,16 +550,12 @@ Compiler::procPar()
 
   if(!current_paradigm.empty() && paradigm_name == current_paradigm)
   {
-    std::cerr << "Error (" << xmlTextReaderGetParserLineNumber(reader);
-    std::cerr << "): Paradigm refers to itself '" << paradigm_name << "'." << std::endl;
-    exit(EXIT_FAILURE);
+    XMLParseUtil::error_and_die(reader, "Paradigm refers to itself '%S'.", paradigm_name.c_str());
   }
 
   if(paradigms.find(paradigm_name) == paradigms.end())
   {
-    std::cerr << "Error (" << xmlTextReaderGetParserLineNumber(reader);
-    std::cerr << "): Undefined paradigm '" << paradigm_name << "'." << std::endl;
-    exit(EXIT_FAILURE);
+    XMLParseUtil::error_and_die(reader, "Undefined paradigm '%S'.", paradigm_name.c_str());
   }
   e.setParadigm(paradigm_name);
   return e;
@@ -604,9 +590,7 @@ Compiler::insertEntryTokens(std::vector<EntryToken> const &elements)
       }
       else
       {
-        std::cerr << "Error (" << xmlTextReaderGetParserLineNumber(reader);
-        std::cerr << "): Invalid entry token." << std::endl;
-        exit(EXIT_FAILURE);
+	XMLParseUtil::error_and_die(reader, "Invalid entry token.");
       }
     }
     t.setFinal(e, default_weight);
@@ -826,8 +810,7 @@ Compiler::procEntry()
 
     while(name != COMPILER_ENTRY_ELEM)
     {
-      xmlTextReaderRead(reader);
-      name = XMLParseUtil::readName(reader);
+      step(name);
     }
 
     return;
@@ -864,16 +847,11 @@ Compiler::procEntry()
     elements.push_back(e);
   }
 
-  while(true)
-  {
-    int ret = xmlTextReaderRead(reader);
-    if(ret != 1)
-    {
-      std::cerr << "Error (" << xmlTextReaderGetParserLineNumber(reader);
-      std::cerr << "): Parse error." << std::endl;
-      exit(EXIT_FAILURE);
-    }
-    UString name = XMLParseUtil::readName(reader);
+  bool contentful = !xmlTextReaderIsEmptyElement(reader);
+  // do nothing if it's <e/>, but while(true) otherwise
+  while (contentful) {
+    UString name;
+    step(name);
     skipBlanks(name);
 
     if(current_paradigm.empty() && verbose)
@@ -909,17 +887,14 @@ Compiler::procEntry()
       auto it = paradigms.find(p);
       if(it == paradigms.end())
       {
-        std::cerr << "Error (" << xmlTextReaderGetParserLineNumber(reader);
-        std::cerr << "): Undefined paradigm '" << p << "'." << std::endl;
-        exit(EXIT_FAILURE);
+	XMLParseUtil::error_and_die(reader, "Undefined paradigm '%S'.", p.c_str());
       }
       // discard entries with empty paradigms (by the directions, normally)
       if(it->second.isEmpty())
       {
         while(name != COMPILER_ENTRY_ELEM || type != XML_READER_TYPE_END_ELEMENT)
         {
-          xmlTextReaderRead(reader);
-          name = XMLParseUtil::readName(reader);
+          step(name);
           type = xmlTextReaderNodeType(reader);
         }
         return;
@@ -936,10 +911,7 @@ Compiler::procEntry()
     }
     else
     {
-      std::cerr << "Error (" << xmlTextReaderGetParserLineNumber(reader);
-      std::cerr << "): Invalid inclusion of '<" << name << ">' into '<" << COMPILER_ENTRY_ELEM;
-      std::cerr << ">'." << std::endl;
-      exit(EXIT_FAILURE);
+      XMLParseUtil::error_and_die(reader, "Invalid inclusion of '<%S>' into '<e>'.", name.c_str());
     }
   }
 }
@@ -965,11 +937,13 @@ Compiler::procNode()
       alphabet.includeSymbol(Transducer::LSX_BOUNDARY_SYMBOL);
       alphabet.includeSymbol(Transducer::LSX_BOUNDARY_SPACE_SYMBOL);
       alphabet.includeSymbol(Transducer::LSX_BOUNDARY_NO_SPACE_SYMBOL);
+      alphabet.includeSymbol(Transducer::READING_SEPARATOR_SYMBOL);
       any_tag          = alphabet(Transducer::ANY_TAG_SYMBOL);
       any_char         = alphabet(Transducer::ANY_CHAR_SYMBOL);
       word_boundary    = alphabet(Transducer::LSX_BOUNDARY_SYMBOL);
       word_boundary_s  = alphabet(Transducer::LSX_BOUNDARY_SPACE_SYMBOL);
       word_boundary_ns = alphabet(Transducer::LSX_BOUNDARY_NO_SPACE_SYMBOL);
+      reading_boundary = alphabet(Transducer::READING_SEPARATOR_SYMBOL);
     }
   }
   else if(name == COMPILER_ALPHABET_ELEM)
@@ -1013,9 +987,7 @@ Compiler::procNode()
   }
   else
   {
-    std::cerr << "Error (" << xmlTextReaderGetParserLineNumber(reader);
-    std::cerr << "): Invalid node '<" << name << ">'." << std::endl;
-    exit(EXIT_FAILURE);
+    XMLParseUtil::error_and_die(reader, "Invalid node '<%S>'.", name.c_str());
   }
 }
 
@@ -1023,9 +995,16 @@ EntryToken
 Compiler::procRegexp()
 {
   EntryToken et;
-  xmlTextReaderRead(reader);
+  UString name;
+  step(name);
+  if (name != COMPILER_TEXT_NODE) {
+    XMLParseUtil::error_and_die(reader, "Invalid inclusion of '<%S>' in '<re>'.", name.c_str());
+  }
   et.readRegexp(reader);
-  xmlTextReaderRead(reader);
+  step(name);
+  if (name != COMPILER_REGEXP_ELEM) {
+    XMLParseUtil::error_and_die(reader, "Invalid inclusion of '<%S>' in '<re>'.", name.c_str());
+  }
   return et;
 }
 
