@@ -46,7 +46,8 @@ int main(int argc, char *argv[])
   cli.add_bool_arg('l', "tagged-gen", "morphological generation keeping lexical forms");
   cli.add_bool_arg('m', "tagged-nm-gen", "same as -l but without unknown word marks");
   cli.add_bool_arg('n', "non-marked-gen", "morph. generation without unknown word marks");
-  cli.add_bool_arg('o', "surf-bilingual", "lexical transfer with surface forms");
+  cli.add_bool_arg('o', "surf-bilingual", "lexical transfer, input has surface forms");
+  cli.add_bool_arg('O', "surf-bilingual-keep", "lexical transfer, input and output has surface forms");
   cli.add_bool_arg('p', "post-generation", "post-generation");
   cli.add_bool_arg('x', "inter-generation", "inter-generation");
   cli.add_bool_arg('s', "sao", "SAO annotation system input processing");
@@ -59,6 +60,7 @@ int main(int argc, char *argv[])
   cli.add_bool_arg('W', "show-weights", "Print final analysis weights (if any)");
   cli.add_str_arg('N', "analyses", "Output no more than N analyses (if the transducer is weighted, the N best analyses)", "N");
   cli.add_str_arg('L', "weight-classes", "Output no more than N best weight classes (where analyses with equal weight constitute a class)", "N");
+  cli.add_str_arg('M', "compound-max-elements", "Set compound max elements", "N");
   cli.add_bool_arg('h', "help", "show this help");
   cli.parse_args(argc, argv);
 
@@ -79,9 +81,15 @@ int main(int argc, char *argv[])
     if (!cmd) cmd = 'b';
     fstp.setBiltransSurfaceForms(true);
   }
+  if (args["surf-bilingual-keep"]) {
+    if (cmd && cmd != 'b') cli.print_usage();
+    if (!cmd) cmd = 'b';
+    fstp.setBiltransSurfaceFormsKeep(true);
+  }
   if (args["generation"]) {
     if (cmd && cmd != 'b') cli.print_usage();
     if (!cmd) cmd = 'g';
+    else if(cmd == 'b') bilmode = gm_bilgen;
   }
   if (args["decompose-nouns"]) {
     if (cmd) cli.print_usage();
@@ -157,6 +165,14 @@ int main(int argc, char *argv[])
     }
     fstp.setMaxWeightClassesValue(n);
   }
+  if (strs.find("compound-max-elements") != strs.end()) { // Test
+    int n = atoi(strs["compound-max-elements"].back().c_str());
+    if (n < 1) {
+      std::cerr << "Invalid or no argument for compound max elements" << std::endl;
+      exit(EXIT_FAILURE);
+    }
+    fstp.setCompoundMaxElements(n);
+  }
 
   FILE* in = openInBinFile(cli.get_files()[0]);
   fstp.load(in);
