@@ -26,9 +26,14 @@ int main(int argc, char *argv[])
   cli.add_file_arg("fst_file", false);
   cli.add_file_arg("input_file");
   cli.add_file_arg("output_file");
+  cli.add_bool_arg('s', "space", "allow a segment to match before space (as well as before punctuation)");
+  cli.add_bool_arg('z', "null-flush", "flush output on the null character (always on, this is a no-op for backwards compatibility)");
   cli.parse_args(argc, argv);
 
+  TranslationMemoryMode tm_mode = cli.get_bools()["space"] ? tm_space : tm_punct;
+
   FSTProcessor fstp;
+  fstp.setNullFlush(true); // cf. description of cli["null-flush"]
   FILE* aux = openInBinFile(cli.get_files()[0]);
   fstp.load(aux);
   fclose(aux);
@@ -43,7 +48,7 @@ int main(int argc, char *argv[])
   }
   UFILE* output = openOutTextFile(cli.get_files()[2].c_str());
 
-  fstp.tm_analysis(input, output);
+  fstp.tm_analysis(input, output, tm_mode);
 
   u_fclose(output);
   return EXIT_SUCCESS;
