@@ -22,10 +22,6 @@
 #include <cstdlib>
 #include <iostream>
 
-UString const PatternList::ANY_CHAR  = "<ANY_CHAR>"_u;
-UString const PatternList::ANY_TAG   = "<ANY_TAG>"_u;
-UString const PatternList::QUEUE     = "<QUEUE>"_u;
-
 void
 PatternList::copy(PatternList const &o)
 {
@@ -80,7 +76,7 @@ PatternList::beginSequence()
 {
   if(sequence)
   {
-    cerr << "Error: opening an unended sequence" << endl;
+    std::cerr << "Error: opening an unended sequence" << std::endl;
     exit(EXIT_FAILURE);
   }
   sequence = true;
@@ -92,23 +88,23 @@ PatternList::endSequence()
 {
   if(!sequence)
   {
-    cerr << "Error: ending an unopened sequence" << endl;
+    std::cerr << "Error: ending an unopened sequence" << std::endl;
     exit(EXIT_FAILURE);
   }
   sequence = false;
 
-  for(list<vector<int> >::iterator it = sequence_data.begin(),
+  for(auto it = sequence_data.begin(),
       limit = sequence_data.end();
       it != limit; it++)
   {
     it->push_back(alphabet(QUEUE));
-    patterns.insert(make_pair(sequence_id, *it));
+    patterns.insert({sequence_id, *it});
   }
 }
 
 void
-PatternList::insertOutOfSequence(UString const &lemma, UString const &tags,
-                                 vector<int> &result)
+PatternList::insertOutOfSequence(UStringView lemma, UStringView tags,
+                                 std::vector<int> &result)
 {
   if(lemma.empty())
   {
@@ -136,9 +132,9 @@ PatternList::insertOutOfSequence(UString const &lemma, UString const &tags,
   {
     for(unsigned int i = 0, limit = tagCount(tags); i < limit; i++)
     {
-      UString tag = "<"_u + tagAt(tags, i) + ">"_u;
+      UString tag = "<"_u + US(tagAt(tags, i)) + ">"_u;
 
-      if(tag == "<*>"_u)
+      if(tag == u"<*>"_uv)
       {
         result.push_back(alphabet(ANY_TAG));
       }
@@ -152,21 +148,20 @@ PatternList::insertOutOfSequence(UString const &lemma, UString const &tags,
 }
 
 void
-PatternList::insertIntoSequence(int const id, UString const &lemma,
-				UString const &tags)
+PatternList::insertIntoSequence(int id, UStringView lemma, UStringView tags)
 {
   sequence_id = id;
 
   if(sequence_data.size() == 0)
   {
-    vector<int> new_vector;
+    std::vector<int> new_vector;
     insertOutOfSequence(lemma, tags, new_vector);
     sequence_data.push_back(new_vector);
   }
   else
   {
-    list<vector<int> >::iterator it    = sequence_data.begin();
-    list<vector<int> >::iterator limit = sequence_data.end();
+    auto it    = sequence_data.begin();
+    auto limit = sequence_data.end();
     for(; it != limit; it++)
     {
       it->push_back('+');
@@ -176,14 +171,14 @@ PatternList::insertIntoSequence(int const id, UString const &lemma,
 }
 
 void
-PatternList::insert(int const id, UString const &lemma, UString const &tags)
+PatternList::insert(int id, UStringView lemma, UStringView tags)
 {
   if(!sequence)
   {
-    vector<int> local;
+    std::vector<int> local;
     insertOutOfSequence(lemma, tags, local);
     local.push_back(alphabet(QUEUE));
-    patterns.insert(make_pair(id, local));
+    patterns.insert({id, local});
   }
   else
   {
@@ -192,11 +187,11 @@ PatternList::insert(int const id, UString const &lemma, UString const &tags)
 }
 
 void
-PatternList::insert(int const id, int const otherid)
+PatternList::insert(int id, int otherid)
 {
   if(!sequence)
   {
-    cerr << "Error: using labels outside of a sequence" << endl;
+    std::cerr << "Error: using labels outside of a sequence" << std::endl;
     exit(EXIT_FAILURE);
   }
 
@@ -212,15 +207,15 @@ PatternList::insert(int const id, int const otherid)
   }
   else
   {
-    list<vector<int> > new_sequence_data;
+    std::list<std::vector<int>> new_sequence_data;
 
-    for(list<vector<int> >::iterator it = sequence_data.begin(),
+    for(auto it = sequence_data.begin(),
           limit = sequence_data.end(); it != limit; it++)
     {
       for(PatternRange p = patterns.equal_range(otherid);
           p.first != p.second; p.first++)
       {
-        vector<int> temp = *it;
+        std::vector<int> temp = *it;
         temp.push_back('+');
         temp.insert(temp.end(), (p.first->second).begin(),
                     (p.first->second).end());
@@ -233,7 +228,7 @@ PatternList::insert(int const id, int const otherid)
 }
 
 int
-PatternList::tagCount(UString const &tags)
+PatternList::tagCount(UStringView tags)
 {
   int count = 0;
 
@@ -252,8 +247,8 @@ PatternList::tagCount(UString const &tags)
   return count;
 }
 
-UString
-PatternList::tagAt(UString const &tags, int const index)
+UStringView
+PatternList::tagAt(UStringView tags, int index)
 {
   int start = 0;
   int end = 0;
@@ -282,7 +277,7 @@ PatternList::tagAt(UString const &tags, int const index)
 
   if(index > count)
   {
-    return ""_u;
+    return u"";
   }
   if(end != 0)
   {
@@ -303,7 +298,7 @@ PatternList::getPatterns()
 void
 PatternList::buildTransducer()
 {
-  for(PatternStore::const_iterator it = patterns.begin(), limit = patterns.end();
+  for(auto it = patterns.begin(), limit = patterns.end();
       it != limit; it++)
   {
     int state = transducer.getInitial();
@@ -366,7 +361,7 @@ void
 PatternList::write(FILE *output)
 {
   alphabet.write(output);
-  UString const tagger_name = "tagger"_u;
+  UStringView tagger_name = u"tagger";
 
   Compression::multibyte_write(1, output);
   Compression::string_write(tagger_name, output);
@@ -374,7 +369,7 @@ PatternList::write(FILE *output)
 
   Compression::multibyte_write(final_type.size(), output);
 
-  for(map<int, int>::const_iterator it = final_type.begin(), limit = final_type.end();
+  for(auto it = final_type.begin(), limit = final_type.end();
       it != limit; it++)
   {
     Compression::multibyte_write(it->first, output);
@@ -408,7 +403,7 @@ PatternList::serialise(std::ostream &serialised) const
 {
   alphabet.serialise(serialised);
   transducer.serialise(serialised);
-  Serialiser<map<int, int> >::serialise(final_type, serialised);
+  Serialiser<std::map<int, int> >::serialise(final_type, serialised);
 }
 
 void
@@ -416,7 +411,7 @@ PatternList::deserialise(std::istream &serialised)
 {
   alphabet.deserialise(serialised);
   transducer.deserialise(serialised);
-  final_type = Deserialiser<map<int, int> >::deserialise(serialised);
+  final_type = Deserialiser<std::map<int, int> >::deserialise(serialised);
 }
 
 MatchExe *
