@@ -17,7 +17,6 @@
 #ifndef _REGEXP_COMPILER_
 #define _REGEXP_COMPILER_
 
-#include <lttoolbox/ustring.h>
 #include <lttoolbox/alphabet.h>
 #include <lttoolbox/transducer.h>
 
@@ -25,10 +24,6 @@
 #include <vector>
 #include <cstdint>
 
-using namespace std;
-
-#define FIN_FICHERO - 1
-
 /**
  * Compiler that builds a transducer to identify regular expressions.  This
  * compiler is a recursive descendent parser (RDP).
@@ -39,22 +34,22 @@ private:
   /**
    * Last token
    */
-  int token;
+  int token = 0;
 
   /**
    * Input string
    */
-  vector<int32_t> input;
+  std::vector<int32_t> input;
 
   /**
    * Location in the input string
    */
-  size_t index;
+  size_t index = 0;
 
   /**
    * Alphabet to encode symbols
    */
-  Alphabet *alphabet;
+  Alphabet *alphabet = nullptr;
 
   /**
    * Transducer to store analysis
@@ -64,27 +59,27 @@ private:
   /**
    * Current state
    */
-  int state;
+  int state = 0;
 
   /**
    * Current letter
    */
-  int letter;
+  int letter = 0;
 
   /**
    * Post-operator: '+', '?', '*'
    */
-  UChar32 postop;
+  UChar32 postop = '\0';
 
   /**
    * Default value of weight
    */
-  double default_weight;
+  double default_weight = 0.0000;
 
   /**
    *
    */
-  set<int> brackets;
+  std::set<int> brackets;
 
   /**
    * Copy method
@@ -92,11 +87,6 @@ private:
    */
   void copy(RegexpCompiler const &rec);
 
-  /**
-   * Destroy method
-   */
-  void destroy();
-
   /**
    * RDP top function
    */
@@ -208,7 +198,7 @@ public:
    * Function that parses a regular expression and produces a transducer
    * @param er the regular expression
    */
-  void compile(vector<int32_t> const &er);
+  void compile(std::vector<int32_t> const &er);
 
   /**
    * Set the decoder of symbols
