@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 import unittest
-from printtest import PrintTest
+from basictest import PrintTest
 
 
 class NonWeightedFst(unittest.TestCase, PrintTest):
