@@ -99,14 +99,14 @@ class GardenPathMwe(ProcTest):
                        "y[A]x",
                         "[A]y x",
                         "legge opp[<br/>]",
-                        "legge[][\n]L[<\/p>\n]",
+                        "legge[][\n]L[<\\/p>\n]",
                        ]
     expectedOutputs = ["^x/*x$[ <br/> ]^opp/opp<pr>$^./.<sent>$",
                         "^legge/legge<vblex><inf>$ ^opp/opp<pr>$[<br/>]^x/*x$^./.<sent>$",
                        "^y/*y$[A]^x/*x$",
                         "[A]^y/*y$ ^x/*x$",
                         "^legge/legge<vblex><inf>$ ^opp/opp<pr>$[<br/>]",
-                        "^legge/legge<vblex><inf>$[][\n]^L/*L$[<\/p>\n]",
+                        "^legge/legge<vblex><inf>$[][\n]^L/*L$[<\\/p>\n]",
                        ]
 
 class GardenPathMweNewlines(ProcTest):
@@ -208,9 +208,9 @@ class PostgenerationWordboundBlankTest(ProcTest):
 class PostgenerationWordboundBlankEscapingTest(ProcTest):
     procdix = "data/postgen.dix"
     procflags = ["-p", "-z"]
-    inputs          = [ "Systran ([[t:a:PJD9GA]]http:\/\/www.systran.de\/[[/]]).[] Systran (http:\/\/www.systran.de\/).[]"]
+    inputs          = [ "Systran ([[t:a:PJD9GA]]http:\\/\\/www.systran.de\\/[[/]]).[] Systran (http:\\/\\/www.systran.de\\/).[]"]
 
-    expectedOutputs = [ "Systran ([[t:a:PJD9GA]]http:\/\/www.systran.de\/[[/]]).[] Systran (http:\/\/www.systran.de\/).[]"]
+    expectedOutputs = [ "Systran ([[t:a:PJD9GA]]http:\\/\\/www.systran.de\\/[[/]]).[] Systran (http:\\/\\/www.systran.de\\/).[]"]
 
 
 class PostgenerationWordboundBlankNoRuleMatchTest(ProcTest):
@@ -432,6 +432,24 @@ class BufferIndex(ProcTest):
                        ]
 
 
+class Bilsurf(ProcTest):
+    """Test --surf-bilingual"""
+    procdix = "data/minimal-bi.dix"
+    procflags = ['-o', '-z']
+    procdir = "lr"
+    inputs = ["^Ab/ab<n><def>$"]
+    expectedOutputs = ["^ab<n><def>/xy<n><def>$"]
+
+class BilsurfKeep(ProcTest):
+    """Test --surf-bilingual-keep"""
+    procdix = "data/minimal-bi.dix"
+    procflags = ['-O', '-z']
+    procdir = "lr"
+    inputs = ["^Ab/ab<n><def>$",
+              "^bad<data>$ ^Ab/ab<n><def>$",]
+    expectedOutputs = ["^Ab/ab<n><def>/xy<n><def>$",
+                       "^bad<data>$ ^Ab/ab<n><def>/xy<n><def>$"]
+
 class Bigen(ProcTest):
     """Test that we can run -b with -g before, and -b should override it."""
     procdix = "data/minimal-mono.dix"
@@ -440,5 +458,103 @@ class Bigen(ProcTest):
     inputs = ["^ab<n><def>$"]
     expectedOutputs = ["^ab<n><def>/abc$"]
 
+class BigenGroup(ProcTest):
+    """Test that bare <g> without tags can be generated in biltrans mode."""
+    procdix = "data/baregroup-mono.dix"
+    procflags = ['-g', '-b', '-z']
+    procdir = "rl"
+    inputs = ["^# fri$", "^# frå kvarandre$"]
+    expectedOutputs = ["^# fri/ fri$", "^# frå kvarandre/ frå kvarandre$"]
+
+class BiltransEscapedAsterisk(ProcTest):
+    procdix = "data/minimal-bi.dix"
+    procflags = ['-b', '-z']
+    procdir = "lr"
+    inputs = ["^*ab<n><def>$", '^\\*ab<n><def>$']
+    expectedOutputs = ["^*ab<n><def>/*ab<n><def>$",
+                       '^\\*ab<n><def>/@\\*ab<n><def>$']
+
+class BiltransGarbage(ProcTest):
+    procflags = ['-b', '-z']
+    inputs = ['^$']
+    expectedOutputs = ['^$']
+
+class BiltransSimple(ProcTest):
+    procflags = ['-b', '-z']
+    inputs = ['^abc$']
+    expectedOutputs = ['^abc/ab<n><def>$']
+
+class SlashesInTags(ProcTest):
+    procdix = 'data/slash-tags.dix'
+    procflags = ['-b', '-z']
+    procdir = 'lr'
+    inputs = ['^\\*lobwana1.1<n><1/2>$',
+              '^\\*lobwana1.1<n><3/4>$',
+              '^\\*lobwana1.1<n><1/2><x>$',
+              '^\\*lobwana1.1<n><3/4><x>$',
+              '^\\*lobwana1.1<n><1/2><a/b>$',
+              '^\\*lobwana1.1<n><3/4><a/b>$']
+    expectedOutputs = ['^\\*lobwana1.1<n><1/2>/*lopwana1.1<n><1/2>$',
+                       '^\\*lobwana1.1<n><3/4>/@\\*lobwana1.1<n><3/4>$',
+                       '^\\*lobwana1.1<n><1/2><x>/*lopwana1.1<n><1/2><x>$',
+                       '^\\*lobwana1.1<n><3/4><x>/@\\*lobwana1.1<n><3/4><x>$',
+                       '^\\*lobwana1.1<n><1/2><a/b>/*lopwana1.1<n><1/2><a/b>$',
+                       '^\\*lobwana1.1<n><3/4><a/b>/@\\*lobwana1.1<n><3/4><a/b>$']
+
+class BiltransAnyChar(ProcTest):
+    procdix = 'data/pass-through.lsx'
+    procflags = ['-b', '-z']
+    # Using r'' to avoid doubling escapes even more:
+    inputs = [r'^simple<MERGED>$']
+    expectedOutputs = [r'^simple<MERGED>/simple<MERGED>$']
+
+
+class BiltransAnyCharEscapes(ProcTest):
+    procdix = 'data/pass-through.lsx'
+    procflags = ['-b', '-z']
+    # Using r'' to avoid doubling escapes even more:
+    inputs = [r'^«\[\[tf:i:a\]\]s\\\^å\[\[\/\]\]»<MERGED>$']
+    expectedOutputs = [r'^«\[\[tf:i:a\]\]s\\\^å\[\[\/\]\]»<MERGED>/«\[\[tf:i:a\]\]s\\\^å\[\[\/\]\]»<MERGED>$']
+
+class BiltransGenDebugSymbols(ProcTest):
+    procdix = 'data/minimal-mono.dix'
+    procdir = 'rl'
+    procflags = ['-d', '-b']
+    inputs = [
+        '^ab<n><def>$',
+        '^ab<n><def><potato>$',
+        '^ab<n><def>#c$',
+    ]
+    expectedOutputs = [
+        '^ab<n><def>/abc$',
+        '^ab<n><def><potato>/#ab<n><def><potato>$',
+        '^ab<n><def>#c/#ab<n><def>#c$',
+    ]
+
+class BiltransLowerFallback(ProcTest):
+    procdix = 'data/big-mono.dix'
+    procdir = 'rl'
+    procflags = ['-g', '-b', '-z']
+    inputs = [
+        '^HJERTERYTMEOVERVÅKNING<n><def>$',
+    ]
+    expectedOutputs = [
+        '^HJERTERYTMEOVERVÅKNING<n><def>/hjerterytmeovervåkningen$',
+    ]
+
+class AnalysisLowerFallback(ProcTest):
+    procdix = 'data/big-mono.dix'
+    procdir = 'lr'
+    procflags = ['-w', '-e', '-z']
+    inputs = [
+        'Vas vas',
+        'hjerterytmeovervåkningen hjerteklaffovervåkningen HJERTERYTMEOVERVÅKNINGEN HJERTEKLAFFOVERVÅKNINGEN',
+    ]
+    expectedOutputs = [
+        '^Vas/*Vas$ ^vas/*vas$',
+        '^hjerterytmeovervåkningen/hjerterytmeovervåkning<n><def>$ ^hjerteklaffovervåkningen/hjerteklaff<n>+overvåkning<n><def>$ ^HJERTERYTMEOVERVÅKNINGEN/hjerterytmeovervåkning<n><def>$ ^HJERTEKLAFFOVERVÅKNINGEN/hjerteklaff<n>+overvåkning<n><def>$'
+    ]
+
+
 # These fail on some systems:
 #from null_flush_invalid_stream_format import *
