@@ -10,7 +10,9 @@ if len(sys.argv) > 1:
     os.environ['LTTOOLBOX_PATH'] = sys.argv[1]
 
 modules = ['lt_proc', 'lt_trim', 'lt_print', 'lt_comp', 'lt_append',
-           'lt_paradigm', 'lt_expand', 'lt_apply_acx', 'lt_compose']
+           'lt_paradigm', 'lt_expand', 'lt_apply_acx', 'lt_compose',
+           'lt_tmxproc', 'lt_merge']
+
 
 if __name__ == "__main__":
     os.chdir(os.path.dirname(__file__))
